@@ -1,14 +1,17 @@
+#!/usr/bin/env python
 """
 A command-line wrapper for mafan encoding
 """
+import os
+import sys
 
-from mafan import convert
+from mafan import encoding
 
 if __name__ == '__main__':
   try:
     fname = sys.argv[1]
     if fname and os.path.isfile(fname):
-      new_fname = convert(sys.argv[1])
+      new_fname = encoding.convert(sys.argv[1])
       if new_fname:
         print "File created! %s" % new_fname
       else:
